@@ -4,7 +4,7 @@ use Log::Log4perl;
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
 	my ($class, $conf_file, $watch) = (@_);
@@ -50,27 +50,28 @@ sub new {
 
         *{ __PACKAGE__ . "::$level" } =
             sub {
+                my $self = shift;
                 local $Log::Log4perl::caller_depth =
                    $Log::Log4perl::caller_depth + 1;
-                shift->_get_logger->$level(@_);
+                $self->_get_logger->$level(@_);
+                return $self;
             };
     }
 }
 
 sub log {
-    my ($self, $level, @msgs) = @_;
+	my ($self, $level, @msgs) = @_;
 
 	my $logger = $self->_get_logger();
     
-    # Check
-    $level = lc $level;
+	# Check
+	$level = lc $level;
 	if ($level =~ m/^(?:trace|debug|info|warn|error|fatal)$/o) {
-        local $Log::Log4perl::caller_depth =
-            $Log::Log4perl::caller_depth + 1;
+		local $Log::Log4perl::caller_depth =
+		   $Log::Log4perl::caller_depth + 1;
 		$logger->$level(@msgs);
 	}
-	
-    return $self;
+	return $self;
 }
 
 sub is_trace { shift->_get_logger->is_trace }
@@ -101,22 +102,22 @@ sub level {
 	my ($self, $level) = (@_);
 	my $logger = $self->_get_logger;
 
-    require Log::Log4perl::Level;
-    if ($level) {
-    	return $logger->level( Log::Log4perl::Level::to_priority(uc $level) );
-    }
-    else {
+	require Log::Log4perl::Level;
+	if ($level) {
+		return $logger->level( Log::Log4perl::Level::to_priority(uc $level) );
+	}
+	else {
 		return Log::Log4perl::Level::to_level( $logger->level() );
-    }
+	}
 }
 
 sub _get_logger {
-    # get our caller
-    my ($pkg, $line) = (caller())[0, 2];
-    ($pkg, $line) = (caller(1))[0, 2] if $pkg eq ref shift;
+	# get our caller
+	my ($pkg, $line) = (caller())[0, 2];
+	($pkg, $line) = (caller(1))[0, 2] if $pkg eq ref shift;
 
-    # get correct logger for our caller
-    my $logger = Log::Log4perl->get_logger($pkg);
+	# get correct logger for our caller
+	my $logger = Log::Log4perl->get_logger($pkg);
 	return $logger;
 }
 
@@ -236,6 +237,8 @@ Below are all log levels from MojoX::Log::Log4perl, in descending priority:
 
 Just like C<< Log::Log4perl >>: "If your configured logging level is WARN, then messages logged with info(), debug(), and trace() will be suppressed. fatal(), error() and warn() will make their way through, because their priority is higher or equal than the configured setting."
 
+The return value is the log object itself, to allow method chaining and further manipulation.
+
 =head2 C<log>
 
 You can also use the C<< log() >> method just like in C<< Mojo::Log >>:
@@ -244,6 +247,8 @@ You can also use the C<< log() >> method just like in C<< Mojo::Log >>:
 
 But nobody does that, really.
 
+As with the regular logging methods, the return value is the log object itself.
+
 =head1 CHECKING LOG LEVELS
 
   if ($logger->is_debug) {
@@ -401,7 +406,7 @@ L<< Log::Log4perl >>, L<< Mojo::Log >>, L<< Mojo >>, L<< Mojolicious >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2011 Breno G. de Oliveira, all rights reserved.
+Copyright 2009-2012 Breno G. de Oliveira, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
